#ifndef SETTINGS_H
#define SETTINGS_H

#include "guicast.h"
#include "mainwindow.inc"
#include "mutex.h"
#include "thread.h"

class SettingsWindow;

class SettingsThread : public Thread
{
public:
	SettingsThread(MainWindow *mwindow);
	~SettingsThread();

	void run();
	int update_framerate();

	MainWindow *mwindow;
	float aspect_w, aspect_h;
	float letter_w, letter_h;
	int square_pixels;
	int crop_letterbox;
	int smp;
	long prebuffer_size;
	int thread_running;
	int convert_601;
	int audio_priority;
	int mmx;
	SettingsWindow *window;
	Mutex change_lock;
};


class SettingsWindow : public BC_Window
{
public:
	SettingsWindow(MainWindow *mwindow, SettingsThread *thread);
	~SettingsWindow();
	
	int initialize();
	
	MainWindow *mwindow;
	SettingsThread *thread;
	BC_Title *frame_rate;
	ArrayList<BC_ListBoxItem*> aspect_ratios;
};

class SettingsW : public BC_TextBox
{
public:
	SettingsW(SettingsThread *thread, int x, int y, char *string);
	~SettingsW();
	
	int handle_event();
	
	SettingsThread *thread;
};

class SettingsH : public BC_TextBox
{
public:
	SettingsH(SettingsThread *thread, int x, int y, char *string);
	~SettingsH();
	
	int handle_event();
	
	SettingsThread *thread;
};

class SettingsLetterW : public BC_TextBox
{
public:
	SettingsLetterW(SettingsThread *thread, int x, int y, char *string);
	~SettingsLetterW();
	int handle_event();
	SettingsThread *thread;
};

class SettingsLetterH : public BC_TextBox
{
public:
	SettingsLetterH(SettingsThread *thread, int x, int y, char *string);
	~SettingsLetterH();
	int handle_event();
	SettingsThread *thread;
};

class SettingsEnableAspect : public BC_CheckBox
{
public:
	SettingsEnableAspect(SettingsThread *thread, int x, int y);
	~SettingsEnableAspect();
	int handle_event();
	SettingsThread *thread;
};

class SettingsEnableLetter : public BC_CheckBox
{
public:
	SettingsEnableLetter(SettingsThread *thread, int x, int y);
	~SettingsEnableLetter();
	int handle_event();
	SettingsThread *thread;
};

class SettingsEnable601 : public BC_CheckBox
{
public:
	SettingsEnable601(SettingsThread *thread, int x, int y);
	~SettingsEnable601();
	int handle_event();
	SettingsThread *thread;
};

class SettingsSMP : public BC_CheckBox
{
public:
	SettingsSMP(SettingsThread *thread, int x, int y);
	~SettingsSMP();
	
	int handle_event();
	
	SettingsThread *thread;
};

class SettingsMMX : public BC_CheckBox
{
public:
	SettingsMMX(SettingsThread *thread, int x, int y);
	~SettingsMMX();
	
	int handle_event();
	
	SettingsThread *thread;
};

class SettingsPrebuff : public BC_TextBox
{
public:
	SettingsPrebuff(SettingsThread *thread, int x, int y, char *string);
	~SettingsPrebuff();
	int handle_event();
	SettingsThread *thread;
};

class SettingsAudioPri : public BC_TextBox
{
public:
	SettingsAudioPri(SettingsThread *thread, int x, int y, char *string);
	~SettingsAudioPri();
	int handle_event();
	SettingsThread *thread;
};


class AspectPulldown : public BC_ListBox
{
public:
	AspectPulldown(SettingsWindow *window, 
		int x, 
		int y, 
		BC_TextBox *textbox_w, 
		BC_TextBox *textbox_h,
		float *output_w, 
		float *output_h);

	int handle_event();
private:
	SettingsWindow *window;
	BC_TextBox *textbox_w;
	BC_TextBox *textbox_h;
	float *output_w;
	float *output_h;
};


#endif
